
from top.api.base import RestApi
class TbkActivityInfoGetRequest(RestApi):
    def __init__(self,domain='gw.api.taobao.com',port=80):
        RestApi.__init__(self,domain, port)

        # mm_xxx_xxx_xxx的第三位
        self.adzone_id = None
        # mm_xxx_xxx_xxx 仅三方分成场景使用
        self.sub_pid = None
        # 代理id
        self.relation_id = None
        # 官方活动物料id，由官方运营提供或从官方平台上获取
        self.activity_material_id = None
        # 自定义输入串，英文和数字组成，长度不能大于12个字符，区分不同的推广渠道
        self.union_id = None

    def getapiname(self):
        return 'taobao.tbk.activity.info.get'





from top.api.base import RestApi
class TbkScPublisherInfoSaveRequest(RestApi):
    def __init__(self,domain='gw.api.taobao.com',port=80):
        RestApi.__init__(self,domain, port)

        # 渠道备案 - 来源，取链接的来源
        self.relation_from = None

        # 渠道备案 - 线下场景信息，1 - 门店，2- 学校，3 - 工厂，4 - 其他
        self.offline_scene = None
        # 渠道备案 - 线上场景信息，1 - 微信群，2- QQ群，3 - 其他
        self.online_scene = None
        # 淘宝客邀请渠道或会员的邀请码
        self.inviter_code = None
        # 类型，必选 默认为1:
        self.info_type = 1
        # 媒体侧渠道备注
        self.note = None
        # 线下备案注册信息,字段包含: 电话号码(phoneNumber，必填),省(province,必填),市(city,必填),区县街道(location,必填),
        # 详细地址(detailAddress,必填),经营类型(career,线下个人必填),店铺类型(shopType,线下店铺必填),店铺名称(shopName,线下店铺必填),
        # 店铺证书类型(shopCertifyType,线下店铺选填),店铺证书编号(certifyNumber,线下店铺选填)
        self.register_info = None

    def getapiname(self):
        return 'taobao.tbk.sc.publisher.info.save'



from top.api.base import RestApi
class TbkOrderDetailsGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		# 查询时间类型，1：按照订单淘客创建时间查询，2:按照订单淘客付款时间查询，3:按照订单淘客结算时间查询
		self.query_type = None
		# 位点，除第一页之外，都需要传递；前端原样返回。
		self.position_index = None
        # 页大小，默认20，1~100
		self.page_size = None
		# 推广者角色类型,2:二方，3:三方，不传，表示所有角色
		self.member_type = None
		# 淘客订单状态，12-付款，13-关闭，14-确认收货，3-结算成功;不传，表示所有状态
		self.tk_status = None
		# 订单查询结束时间，订单开始时间至订单结束时间，中间时间段日常要求不超过3个小时，
		# 但如618、双11、年货节等大促期间预估时间段不可超过20分钟，超过会提示错误，调用时请务必注意时间段的选择，以保证亲能正常调用！
        self.end_time = None
		# 订单查询开始时间
	    self.start_time = None
		# 跳转类型，当向前或者向后翻页必须提供,-1: 向前翻页,1：向后翻页
		self.jump_type = None
		# 第几页，默认1，1~100
		self.page_no = None
		# 场景订单场景类型，1:常规订单，2:渠道订单，3:会员运营订单，默认为1
		self.order_scence = None

	def getapiname(self):
		return 'taobao.tbk.order.details.get'


'''
Created by auto_sdk on 2020.05.28
'''
from top.api.base import RestApi
class TbkItemInfoGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.ip = None
		self.num_iids = None
		self.platform = None

	def getapiname(self):
		return 'taobao.tbk.item.info.get'



from top.api.rest.TbkTpwdCreateRequest import TbkTpwdCreateRequest
from top.api.rest.TbkCouponGetRequest import TbkCouponGetRequest
from top.api.rest.TbkItemInfoGetRequest import TbkItemInfoGetRequest
from top.api.rest.TbkActivityInfoGetRequest import TbkActivityInfoGetRequest
from top.api.rest.TbkScPublisherInfoSaveRequest import TbkScPublisherInfoSaveRequest
from top.api.rest.TbkOrderDetailsGetRequest import TbkOrderDetailsGetRequest